Appendix — Python XMP Toolkit v1.0b3 documentation

### Navigation

- index
- modules |
- previous |
- Python XMP Toolkit v1.0b3 documentation »

# Appendix

## Resources

> - Project website – http://code.google.com/p/python-avm-library/
> - Virtual Astronomy – http://www.virtualastronomy.org
> - Python-XMP-Library – http://code.google.com/p/python-xmp-toolkit/
> - XMP – http://www.adobe.com/products/xmp/

## Glossary

AVM
  Astronomy Visualization Metadata

## TODO list

Todo

Improve avm_to_file function. Add ability to input an XMP file

(The original entry is located in reference.rst, line 41.)

Todo

Redo this function. Implement the dash functionality only for ordered lists.

(The original entry is located in reference.rst, line 13.)

Todo

Redo this function. Implement the dash functionality only for ordered lists.

(The original entry is located in reference.rst, line 13.)

Todo

Implement a better way to determine class.

(The original entry is located in reference.rst, line 13.)

## License

Copyright (c) 2008-2009, European Space Agency & European Southern Observatory (ESA/ESO)

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

> - Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
> - Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
> - Neither the name of the European Space Agency, European Southern Observatory nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY ESA/ESO ``AS IS’’ AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL ESA/ESO BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

## Changes

Release 1.0beta1 (May 29, 2009)
  - First public release.

### Navigation

- index
- modules |
- previous |
- Python XMP Toolkit v1.0b3 documentation »